#[repr(transparent)]pub struct Pill {
inner: TypedObjectRef<Pill, <Pill as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
Inline widget displaying an emphasized PillSource.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Pill, <Pill as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Pill
impl Pill
Sourcepub fn source(&self) -> <BoundObject<PillSource> as Property>::Value
pub fn source(&self) -> <BoundObject<PillSource> as Property>::Value
The source of the data displayed by this widget.
Sourcepub fn set_source<'a>(
&self,
value: Option<impl Borrow<<<BoundObject<PillSource> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_source<'a>( &self, value: Option<impl Borrow<<<BoundObject<PillSource> as Property>::Value as HasParamSpec>::SetValue>>, )
The source of the data displayed by this widget.
Sourcepub fn activatable(&self) -> <Cell<bool> as Property>::Value
pub fn activatable(&self) -> <Cell<bool> as Property>::Value
Whether the pill can be activated.
Sourcepub fn set_activatable<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_activatable<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the pill can be activated.
Sourcepub fn watched_safety_setting(
&self,
) -> <PhantomData<AvatarImageSafetySetting> as Property>::Value
pub fn watched_safety_setting( &self, ) -> <PhantomData<AvatarImageSafetySetting> as Property>::Value
The safety setting to watch to decide whether the image of the avatar should be displayed.
Sourcepub fn set_watched_safety_setting<'a>(
&self,
value: impl Borrow<<<PhantomData<AvatarImageSafetySetting> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_watched_safety_setting<'a>( &self, value: impl Borrow<<<PhantomData<AvatarImageSafetySetting> as Property>::Value as HasParamSpec>::SetValue>, )
The safety setting to watch to decide whether the image of the avatar should be displayed.
Sourcepub fn watched_room(&self) -> <PhantomData<Option<Room>> as Property>::Value
pub fn watched_room(&self) -> <PhantomData<Option<Room>> as Property>::Value
The room to watch to apply the current safety settings.
This is required if watched_safety_setting is not None.
Sourcepub fn set_watched_room<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<Room>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_watched_room<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<Room>> as Property>::Value as HasParamSpec>::SetValue>>, )
The room to watch to apply the current safety settings.
This is required if watched_safety_setting is not None.
Sourcepub fn connect_source_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_source_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the source property
Sourcepub fn connect_activatable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activatable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the activatable property
Sourcepub fn connect_watched_safety_setting_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_watched_safety_setting_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the watched-safety-setting property
Sourcepub fn connect_watched_room_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_watched_room_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the watched-room property
Sourcepub fn notify_source(&self)
pub fn notify_source(&self)
Notify listeners of a change in the source property
Sourcepub fn notify_activatable(&self)
pub fn notify_activatable(&self)
Notify listeners of a change in the activatable property
Sourcepub fn notify_watched_safety_setting(&self)
pub fn notify_watched_safety_setting(&self)
Notify listeners of a change in the watched-safety-setting property
Sourcepub fn notify_watched_room(&self)
pub fn notify_watched_room(&self)
Notify listeners of a change in the watched-room property
Sourceimpl Pill
impl Pill
Sourcepub fn new(
source: &impl IsA<PillSource>,
watched_safety_setting: AvatarImageSafetySetting,
watched_room: Option<Room>,
) -> Self
pub fn new( source: &impl IsA<PillSource>, watched_safety_setting: AvatarImageSafetySetting, watched_room: Option<Room>, ) -> Self
Create a pill with the given source and watching the given safety setting.